.. _EFLRs:

EFLR objects
------------
*Explicitly Formatted Logical Records* are meant for representing metadata according to pre-defined schemes.
More than 20 such schemes are defined (see :ref:`Implemented EFLRs`).
Each one lists a specific set of attributes.
Some of the EFLRs are required for a DLIS file: :ref:`File Header`, :ref:`Origin`,
:ref:`Frame`, and :ref:`Channel`\ s. Others are optional ways of specifying more metadata.

.. toctree::
   setanditem
   implemented
   relations
